@@ -51,6 +51,7 @@
 #include "gtkhtml-stream.h"
 #include "gtkhtml-private.h"
 #include "gtkhtml-properties.h"
+#include "math.h"
 #include <libgnome/gnome-util.h>
 
 
@@ -809,6 +810,8 @@ on_object (GtkWidget *widget, GdkWindow *window, HTMLObject *obj)
 	}
 }
 
+#define HTML_DIST(x,y) sqrt(x*x + y*y)
+
 static gint
 mouse_change_pos (GtkWidget *widget, GdkWindow *window, gint x, gint y)
 {
@@ -845,7 +848,8 @@ mouse_change_pos (GtkWidget *widget, GdkWindow *window, gint x, gint y)
 			}
 		}
 
-		if (x + engine->x_offset != html->selection_x1 || y + engine->y_offset != html->selection_y1)
+		if (HTML_DIST ((x + engine->x_offset - html->selection_x1),
+			  (y + engine->y_offset - html->selection_y1)) > 4)
 			html->in_selection = TRUE;
 
 		need_scroll = FALSE;
@@ -1363,12 +1367,12 @@ client_notify_widget (GConfClient* client,
 	g_assert (tkey);
 
 	if (!strcmp (tkey, "/font_variable_family")) {
-		g_free (prop->font_var_family);
-		prop->font_var_family = gconf_client_get_string (client, entry->key, NULL);
+		g_free (prop->font_var);
+		prop->font_var = gconf_client_get_string (client, entry->key, NULL);
 		set_fonts (html);
 	} else if (!strcmp (tkey, "/font_fixed_family")) {
-		g_free (prop->font_fix_family);
-		prop->font_fix_family = gconf_client_get_string (client, entry->key, NULL);
+		g_free (prop->font_fix);
+		prop->font_fix = gconf_client_get_string (client, entry->key, NULL);
 		set_fonts (html);
 	} else if (!strcmp (tkey, "/font_variable_size")) {
 		prop->font_var_size = gconf_client_get_int (client, entry->key, NULL);
@@ -1889,7 +1893,8 @@ gtk_html_allow_selection (GtkHTML *html,
 
 /* #define LOG_INPUT */
 #ifdef LOG_INPUT
-static FILE *log_file;
+static FILE *log_file = NULL;
+static gint  log_num = 1;
 #endif
 
 GtkHTMLStream *
@@ -1904,7 +1909,12 @@ gtk_html_begin_content (GtkHTML *html, gchar *content_type)
 	GtkHTMLStream *handle;
 
 #ifdef LOG_INPUT
-	log_file = fopen ("gtkhtml.log", "w+");
+	gchar *fname = g_strdup_printf ("gtkhtml.log.%d", log_num);
+	log_num ++;
+	if (log_file)
+		fclose (log_file);
+	log_file = fopen (fname, "w+");
+	g_free (fname);
 #endif
 	g_return_val_if_fail (! gtk_html_get_editable (html), NULL);
 
@@ -1939,7 +1949,9 @@ gtk_html_end (GtkHTML *html,
 	      GtkHTMLStreamStatus status)
 {
 #ifdef LOG_INPUT
-	fclose (log_file);
+	if (log_file)
+		fclose (log_file);
+	log_file = NULL;
 #endif
 	gtk_html_stream_close (handle, status);
 
@@ -2293,9 +2305,12 @@ gtk_html_set_default_content_type (GtkHTML *html, gchar *content_type)
 
 	g_free (html->priv->content_type);	
 
-	lower = g_strdup (content_type);
-	g_strdown (lower);
-	html->priv->content_type = lower;
+	if (content_type) {
+		lower = g_strdup (content_type);
+		g_strdown (lower);
+		html->priv->content_type = lower;
+	} else
+		html->priv->content_type = NULL;
 }
 
 gpointer
