@@ -395,29 +395,6 @@ delete_object (HTMLEngine *e, HTMLObject **ret_object, guint *ret_len, HTMLUndoD
 		HTMLObject *object;
 		guint len;
 
-		/* if (e->mark->position < e->cursor->position) {
-			HTMLCursor *tmp;
-
-			tmp = e->cursor;
-			e->cursor = e->mark;
-			e->mark = tmp;
-		}
-
-		{
-			HTMLObject *obj;
-			gint off;
-
-			html_cursor_get_left (e->cursor, &obj, &off);
-			if (obj) {
-				e->cursor->object = obj;
-				e->cursor->offset = off;
-			}
-		}
-		if (!e->cursor->object || (e->cursor->object->prev == NULL && e->cursor->offset == 0)) {
-			e->cursor->object = e->mark->object;
-			e->cursor->offset = 0;
-			} */
-
 		delete_object_do (e, &object, &len);
 		if (ret_object && ret_len) {
 			*ret_object = html_object_op_copy (object, e, NULL, NULL, ret_len);
@@ -565,7 +542,8 @@ html_engine_paste (HTMLEngine *e)
 static void
 check_magic_link (HTMLEngine *e, const gchar *text, guint len)
 {
-	if (GTK_HTML_PROPERTY (e->widget, magic_links) && len == 1
+	if (HTML_OBJECT_TYPE (e->cursor->object) == HTML_TYPE_TEXT
+	    && GTK_HTML_PROPERTY (e->widget, magic_links) && len == 1
 	    && (*text == ' ' || text [0] == '\n' || text [0] == '>' || text [0] == ')'))
 		html_text_magic_link (HTML_TEXT (e->cursor->object), e, html_object_get_length (e->cursor->object));
 }
@@ -618,12 +596,10 @@ html_engine_insert_text (HTMLEngine *e, const gchar *text, guint len)
 			o = html_engine_new_text (e, text, alen);
 			html_text_convert_nbsp (HTML_TEXT (o), TRUE);
 
-			if (alen == 1) {
-				if (html_is_in_word (html_text_get_char (HTML_TEXT (o), 0)))
+			if (alen == 1 && html_is_in_word (html_text_get_char (HTML_TEXT (o), 0))
+			    && !html_is_in_word (html_cursor_get_current_char (e->cursor)))
 					e->need_spell_check = TRUE;
-				else if (e->need_spell_check)
-					html_engine_spell_check_range (e, e->cursor, e->cursor);
-			} else
+			else
 				check = TRUE;
 			insert_object (e, o, html_object_get_length (o), HTML_UNDO_UNDO, check);
 		}
