@@ -24,12 +24,18 @@
     <Daniel.Veillard@w3.org>.
 */
 
+#include <config.h>
 #include <string.h>
-
-#include "htmlengine.h"
-#include "htmlentity.h"
-#include "gtkhtmldebug.h"
+#include <unicode.h>
 #include "config.h"
+#include "htmlcolor.h"
+#include "htmlengine.h"
+#include "htmlimage.h"
+#include "htmlentity.h"
+#include "htmlengine-save.h"
+#include "htmlsettings.h"
+
+#include "gtkhtmldebug.h"
 
 
 /* This routine was originally written by Daniel Velliard, (C) 1998 World Wide
@@ -184,19 +190,46 @@ color_to_string (gchar *s, HTMLColor *c)
 {
 	gchar color [20];
 
-	g_snprintf (color, 20, "%s=\"#%2x%2x%2x\" ", s, c->color.red >> 8, c->color.green >> 8, c->color.blue >> 8);
+	g_snprintf (color, 20, " %s=\"#%2x%2x%2x\"", s, c->color.red >> 8, c->color.green >> 8, c->color.blue >> 8);
 	return g_strdup (color);
 }
 
+static gchar *
+get_body (HTMLEngine *e)
+{
+	HTMLColorSet *cset;
+	gchar *body;
+	gchar *text;
+	gchar *bg;
+	gchar *bg_image;
+	gchar *link;
+	gchar *url = NULL;
+
+	cset = e->settings->color_set;
+	text = (cset->changed [HTMLTextColor]) ? color_to_string ("TEXT", cset->color [HTMLTextColor]) : g_strdup ("");
+	link = (cset->changed [HTMLLinkColor]) ? color_to_string ("LINK", cset->color [HTMLLinkColor]) : g_strdup ("");
+	bg   = (cset->changed [HTMLBgColor]) ? color_to_string ("BGCOLOR", cset->color [HTMLBgColor]) : g_strdup ("");
+	bg_image = e->bgPixmapPtr ? g_strdup_printf (" BACKGROUND=\"%s\"",
+						     url = html_image_resolve_image_url
+						     (e->widget, ((HTMLImagePointer *) e->bgPixmapPtr)->url))
+		: g_strdup ("");
+	g_free (url);
+
+	body = g_strconcat ("<BODY", text, link, bg, bg_image, ">", NULL);
+
+	g_free (text);
+	g_free (link);
+	g_free (bg);
+	g_free (bg_image);
+
+	return body;
+}
+
 static gboolean
 write_header (HTMLEngineSaveState *state)
 {
-	HTMLColorSet *cset;
 	gboolean retval = TRUE;
 	gchar *body;
-	gchar *text;
-	gchar *bg;
-	gchar *link;
 
 	/* Preface.  */
 	if (! html_engine_save_output_string
@@ -228,19 +261,10 @@ write_header (HTMLEngineSaveState *state)
 		return FALSE;
 
 	/* Start of body.  */
-
-	cset = state->engine->settings->color_set;
-	text = (cset->changed [HTMLTextColor]) ? color_to_string ("TEXT", cset->color [HTMLTextColor]) : g_strdup ("");
-	link = (cset->changed [HTMLLinkColor]) ? color_to_string ("LINK", cset->color [HTMLLinkColor]) : g_strdup ("");
-	bg   = (cset->changed [HTMLBgColor]) ? color_to_string ("BGCOLOR", cset->color [HTMLBgColor]) : g_strdup ("");
-
-	body = g_strconcat ("<BODY ", text, link, bg, ">", NULL);
-	if (! html_engine_save_output_string (state, body))
+	body = get_body (state->engine);
+	if (!html_engine_save_output_string (state, "%s", body))
 		retval = FALSE;
 	g_free (body);
-	g_free (text);
-	g_free (link);
-	g_free (bg);
 
 	return retval;
 }
@@ -255,7 +279,7 @@ write_end (HTMLEngineSaveState *state)
 }
 
 gboolean
-html_engine_save (const HTMLEngine *engine,
+html_engine_save (HTMLEngine *engine,
 		  HTMLEngineSaveReceiverFn receiver,
 		  gpointer user_data)
 {
@@ -289,7 +313,7 @@ html_engine_save (const HTMLEngine *engine,
 }
 
 gboolean
-html_engine_save_plain (const HTMLEngine *engine,
+html_engine_save_plain (HTMLEngine *engine,
 			HTMLEngineSaveReceiverFn receiver,
 			gpointer user_data)
 {
@@ -319,7 +343,7 @@ html_engine_save_plain (const HTMLEngine *engine,
 
 static gboolean
 html_engine_save_buffer_receiver (const HTMLEngine *engine,
-				  const            *data,
+				  const gchar      *data,
 				  guint             len,
 				  gpointer          user_data)
 {
@@ -359,7 +383,7 @@ html_engine_save_buffer_new (HTMLEngine *engine)
 
 	if (state) {
 		state->engine = engine;
-		state->receiver = html_engine_save_buffer_receiver;
+		state->receiver = (HTMLEngineSaveReceiverFn)html_engine_save_buffer_receiver;
 		state->br_count = 0;
 		state->error = FALSE;
 		state->user_data = (gpointer) g_string_new ("");
@@ -369,5 +393,59 @@ html_engine_save_buffer_new (HTMLEngine *engine)
 	return state;
 }
 
+gchar *
+html_engine_save_get_sample_body (HTMLEngine *e,
+				  HTMLObject *o)
+{
+	return get_body (e);
+}
 
+const gchar *
+html_engine_save_get_paragraph_style (GtkHTMLParagraphStyle style)
+{
+	switch (style) {
+	case GTK_HTML_PARAGRAPH_STYLE_NORMAL:
+		return NULL;
+	case GTK_HTML_PARAGRAPH_STYLE_H1:
+		return "h1";
+	case GTK_HTML_PARAGRAPH_STYLE_H2:
+		return "h2";
+	case GTK_HTML_PARAGRAPH_STYLE_H3:
+		return "h3";
+	case GTK_HTML_PARAGRAPH_STYLE_H4:
+		return "h4";
+	case GTK_HTML_PARAGRAPH_STYLE_H5:
+		return "h5";
+	case GTK_HTML_PARAGRAPH_STYLE_H6:
+		return "h6";
+	case GTK_HTML_PARAGRAPH_STYLE_ADDRESS:
+		return "address";
+	case GTK_HTML_PARAGRAPH_STYLE_PRE:
+		return "pre";
+	case GTK_HTML_PARAGRAPH_STYLE_ITEMDOTTED:
+	case GTK_HTML_PARAGRAPH_STYLE_ITEMROMAN:
+	case GTK_HTML_PARAGRAPH_STYLE_ITEMDIGIT:
+		return "li";
+	}
 
+	g_warning ("Unknown GtkHTMLParagraphStyle %d", style);
+
+	return NULL;
+}
+
+const gchar *
+html_engine_save_get_paragraph_align (GtkHTMLParagraphAlignment align)
+{
+	switch (align) {
+	case GTK_HTML_PARAGRAPH_ALIGNMENT_RIGHT:
+		return "right";
+	case GTK_HTML_PARAGRAPH_ALIGNMENT_CENTER:
+		return "center";
+	case GTK_HTML_PARAGRAPH_ALIGNMENT_LEFT:
+		return "left";
+	}
+
+	g_warning ("Unknown GtkHTMLParagraphAlignment %d", align);
+
+	return NULL;
+}
