@@ -352,7 +352,7 @@ draw (HTMLObject *o,
 					 GTK_HTML_ETCH_NONE, image->border);
 		
 	}
-	if (ANIMATIONS (image) &&  image->animation && HTML_OBJECT_TYPE (HTML_OBJECT (painter)) != HTML_TYPE_PRINTER) {
+	if (ANIMATIONS (image) &&  image->animation && ! HTML_IS_PRINTER (painter)) {
 		image->animation->active = TRUE;
 		image->animation->x = base_x;
 		image->animation->y = base_y;
