@@ -224,8 +224,8 @@ merge_word_width (HTMLText *t1, HTMLText *t2, HTMLPainter *p)
 	guint len, i, words;
 
 	/* printf ("before merge '%s' '%s'\n", t1->text, t2->text);
-	debug_word_width (t1);
-	debug_word_width (t2); */
+	   debug_word_width (t1);
+	   debug_word_width (t2); */
 
 	if (!t1->word_width)
 		return;
@@ -245,8 +245,9 @@ merge_word_width (HTMLText *t1, HTMLText *t2, HTMLPainter *p)
 	t1->words      = words + t2->words - 1;
 	t1->word_width = g_renew (guint, t1->word_width, t1->words);
 
-	for (i = 0; i < t2->words; i ++)
+	for (i = 1; i < t2->words; i ++)
 		t1->word_width [words + i - 1] = t2->word_width [i] + t1->word_width [words - 1];
+	t1->word_width [words - 1] += t2->word_width [0];
 
 	/* printf ("after merge '%s%s'\n", t1->text, t2->text);
 	   debug_word_width (t1); */
@@ -286,7 +287,7 @@ split_word_width (HTMLText *s, HTMLText *d, HTMLPainter *p, gint offset)
 	/* fill s */
 	if (s->words != words) {
 		s->words = words;
-		g_renew (guint, s->word_width, s->words);
+		s->word_width = g_renew (guint, s->word_width, s->words);
 	}
 
 	if (in_middle) {
@@ -1524,6 +1525,8 @@ paste_link (HTMLEngine *engine, HTMLText *text, gint so, gint eo, gchar *prefix)
 	HTMLObject *new_obj;
 	gchar *href;
 	gchar *base;
+	gint offset;
+	guint position;
 
 	base = g_strndup (html_text_get_text (text, so), html_text_get_index (text, eo) - html_text_get_index (text, so));
 	href = (prefix) ? g_strconcat (prefix, base, NULL) : g_strdup (base);
@@ -1536,13 +1539,14 @@ paste_link (HTMLEngine *engine, HTMLText *text, gint so, gint eo, gchar *prefix)
 		 html_colorset_get_color (engine->settings->color_set, HTMLLinkColor),
 		 href, NULL);
 
-	html_cursor_jump_to_position (engine->cursor, engine, engine->cursor->position + so - engine->cursor->offset);
+	offset   = HTML_OBJECT (text) == engine->cursor->object ? engine->cursor->offset : 0;
+	position = engine->cursor->position;
+
+	html_cursor_jump_to_position (engine->cursor, engine, position + so - offset);
 	html_engine_set_mark (engine);
-	html_cursor_jump_to_position (engine->cursor, engine, engine->cursor->position + eo - engine->cursor->offset);
+	html_cursor_jump_to_position (engine->cursor, engine, position + eo - offset);
 
-	html_undo_level_begin    (engine->undo, "Magic link");
 	html_engine_paste_object (engine, new_obj, eo - so);
-	html_undo_level_end      (engine->undo);
 
 	g_free (href);
 }
@@ -1552,30 +1556,39 @@ html_text_magic_link (HTMLText *text, HTMLEngine *engine, guint offset)
 {
 	regmatch_t pmatch [2];
 	gint i;
+	gboolean rv = FALSE;
+	gint saved_position;
 
 	if (!offset)
 		return FALSE;
 	offset--;
 
+	html_undo_level_begin (engine->undo, "Magic link");
+	saved_position = engine->cursor->position;
+
 	while (html_text_get_char (text, offset) != ' ' && html_text_get_char (text, offset) != ENTITY_NBSP && offset)
 		offset--;
 	if (html_text_get_char (text, offset) == ' ' || html_text_get_char (text, offset) == ENTITY_NBSP)
 		offset++;
 
-	while (offset < text->text_len) {
+	while (offset < text->text_len && !rv) {
 		for (i=0; i<MIM_N; i++) {
 			if (mim [i].preg && !regexec (mim [i].preg, html_text_get_text (text, offset), 2, pmatch, 0)) {
 				gint o = html_text_get_text (text, offset) - text->text;
 				paste_link (engine, text,
 					    unicode_index_to_offset (text->text, pmatch [0].rm_so + o),
 					    unicode_index_to_offset (text->text, pmatch [0].rm_eo + o), mim [i].prefix);
-				return TRUE;
+				rv = TRUE;
+				break;
 			}
 		}
 		offset++;
 	}
 
-	return FALSE;
+	html_undo_level_end (engine->undo);
+	html_cursor_jump_to_position (engine->cursor, engine, saved_position);
+
+	return rv;
 }
 
 /*
