@@ -22,7 +22,7 @@
 #define _HTMLTEXTSLAVE_H_
 
 #include "htmlobject.h"
-#include "htmltextmaster.h"
+#include "htmltext.h"
 
 #define HTML_TEXT_SLAVE(x) ((HTMLTextSlave *) (x))
 #define HTML_TEXT_SLAVE_CLASS(x) ((HTMLTextSlaveClass *) (x))
@@ -30,35 +30,30 @@
 struct _HTMLTextSlave {
 	HTMLObject object;
 
-	HTMLTextMaster *owner;
-	gshort posStart;
-	gshort posLen;
+	HTMLText *owner;
+	guint posStart;
+	guint posLen;
+	guint start_word;
 };
 
 struct _HTMLTextSlaveClass {
 	HTMLObjectClass object_class;
 };
 
-
 HTMLTextSlaveClass html_text_slave_class;
 
-
-void        html_text_slave_type_init   (void);
-void        html_text_slave_class_init  (HTMLTextSlaveClass *klass,
-					 HTMLType            type,
-					 guint               object_size);
-void        html_text_slave_init        (HTMLTextSlave      *slave,
-					 HTMLTextSlaveClass *klass,
-					 HTMLTextMaster     *owner,
-					 gint                posStart,
-					 gint                posLen);
-HTMLObject *html_text_slave_new         (HTMLTextMaster     *owner,
-					 gint                posStart,
-					 gint                posLen);
-
-guint  html_text_slave_get_offset_for_pointer  (HTMLTextSlave *slave,
-						HTMLPainter   *painter,
-						gint           x,
-						gint           y);
-
+void        html_text_slave_type_init               (void);
+void        html_text_slave_class_init              (HTMLTextSlaveClass *klass,
+						     HTMLType            type,
+						     guint               object_size);
+void        html_text_slave_init                    (HTMLTextSlave      *slave,
+						     HTMLTextSlaveClass *klass,
+						     HTMLText           *owner,
+						     guint               posStart,
+						     guint               posLen,
+						     guint               start_word);
+HTMLObject *html_text_slave_new                     (HTMLText           *owner,
+						     guint               posStart,
+						     guint               posLen,
+						     guint               start_word);
 #endif /* _HTMLTEXTSLAVE_H_ */
